red <- paste("<font color=\"red\">")
library(ggplot2)
source("myround.r")

qqplot.data <- function (vec) # argument: vector of numbers
{
  # following four lines from base R's qqline()
  y <- quantile(vec[!is.na(vec)], c(0.25, 0.75))
  x <- qnorm(c(0.25, 0.75))
  slope <- diff(y)/diff(x)
  int <- y[1L] - slope * x[1L]

  d <- data.frame(resids = vec)

  ggplot(d, aes(sample = resids)) + stat_qq() + geom_abline(slope = slope, intercept = int)

}
shinyServer(function(input, output) {

    data <- reactive({ 
        source("clipboard")
        A
    })             
 
   output$text1 <- renderText({
        x<- data()$x
        if(input$ord=="Yes") x <- sort(x)
        if(length(x)<=100) return(c("<h5>",x,"</h5><hr>"))
        c("<h5>",x[1:50],"<br>...<br>",x[(length(x)-49):length(x)],"</h5><hr>")
        
   })   
   output$text2 <- renderText({
          x <- data()$x
          nd <- max(nchar(x))
          a <- paste("<h4>Summary Statistics for",data()$valname,":</h4><table>")
          if("Sample Size" %in% input$which) a <- c(a,paste("<tr><th>Sample Size: </th><th>",length(x),"</th></tr>"))    
          if("Mean" %in% input$which) a <- c(a,paste("<tr><th>Mean: </th><th>",myround(x,mean),"</th></tr>"))    
          if("Median" %in% input$which) a <- c(a,paste("<tr><th>Median: </th><th>",myround(x,median),"</th></tr>"))
          if("Standard Deviation" %in% input$which) a <- c(a,paste("<tr><th>Standard Deviation: </th><th>",myround(x,sd),"</th></tr>"))
          if("First Quartile" %in% input$which) a <- c(a,paste("<tr><th>First Quartile: </th><th>",myround(x,quantile,p=0.25),"</th></tr>"))
          if("Third Quartile" %in% input$which) a <- c(a,paste("<tr><th>Third Quartile: </th><th>",myround(x,quantile,p=0.75),"</th></tr>"))
          if("Interquartile Range" %in% input$which) a <- c(a,paste("<tr><th>Interquartile Range: &nbsp;&nbsp;</th><th>",myround(x,IQR),"</th></tr>"))
      
          if("Other Percentiles" %in% input$which) a <- c(a,paste("<tr><th>",input$p,"<sup>th</sup> Percentile: </th><th>",
                  myround(x,quantile,p=input$p/100),"</th></tr>"))
          a <- c(a,"</table>")
   
   })       
   
   output$table <- renderText({
        x<- data()$x   
        nbin <- input$nbins1
        z <- hist(x,nbin,plot=F)
        counts <- z$counts
        breaks <- z$breaks
        n <- length(counts)
        a <- "<table border=\"1\">"
        a[2] <- "<tr><th>&nbsp; Interval &nbsp;</th>
                    <th>&nbsp; Counts &nbsp;</th>
                    <th>&nbsp; Percentages &nbsp;</th></tr>"
        for(i in 1:n)  {
            a[i+2] <- paste("<tr><th>&nbsp;",breaks[i]," - ",breaks[i+1],
                      "&nbsp;</th><th>&nbsp;",counts[i]," &nbsp;</th>
                      <th>&nbsp;",round(counts[i]/length(x)*100,1)," &nbsp;</th></tr>")
        }
        c(a,"</table>")              
        
   })      
   
   output$plot <- renderPlot({
          dta <- data.frame(x=data()$x,y=rep(0,length(data()$x)))
          if(input$graph=="Histogram") {
                  if(input$bin=="Automatic")
                      bw <- 2*IQR(dta$x)/length(dta$x)^(1/3)
                  else    
                      bw <- diff(range(dta$x))/input$nbins
                  plt <- ggplot(data=dta,aes(x))+
                  geom_histogram(aes(y = ..density..),color="black",fill="white", binwidth = bw)+
                  xlab(x$valname)+ylab("")
                  if(input$fit=="Normal Distribution" | input$fit=="Both") {
                      z <- seq(min(dta$x),max(dta$x),length=250)
                      dz<- dnorm(z,mean(dta$x),sd(dta$x))
                      dta1 <- data.frame(x=z,y=dz)
                      plt <- plt + geom_line(data=dta1,aes(x,y),colour="blue",size=1.5)
                  }  
                  if(input$fit=="Nonparametric Density Estimate" | input$fit=="Both") {
                      z <- density(dta$x)
                      dta1 <- data.frame(x=z$x,y=z$y)
                      plt <- plt + geom_line(data=dta1,aes(x,y),colour="red",size=1.5)
                  }                    
          }        
          if(input$graph=="Boxplot") {
                  plt <- ggplot(data=dta,aes(factor(1,length(x)),x))+ 
                  geom_boxplot()+
                  xlab(x$valname)+ylab("")
          }
          if(input$graph=="Normal Probability Plot") {          
                  plt <- qqplot.data(dta$x)+xlab(x$valname)
          }
          if(input$doPrint=="pdf") {
                pdf("c:/R/output/graph.pdf")
                print(plt)
                dev.off()
          }          
          if(input$doPrint=="png") {
                png("c:/R/output/graph.png")
                print(plt)
                dev.off()
          }          
          plt
   })

   output$appinfo <- renderText({ 
      HTML("<br>&nbsp;<br>&nbsp;<br>&nbsp;<br>
      <a target=\"_blank\" href=\"http://academic.uprm.edu/wrolke/myapps1.htm#none\"><h4>What to do</h4></a><br>
      <h6>Written by: Dr. Wolfgang Rolke<br>Created: 2/22/2016</h6>")
      
  })       

})

