shinyUI(fluidPage(
  tags$head(
      tags$style(HTML("
          table, th, td {
              border: 2px solid black;
              text-align:right;
          }
          
          th, td {
              padding: 10px;
          }    
       "))
  ), 
  
  titlePanel("Exporatory Data Analysis - One Quantitative Variable"),

  sidebarLayout(
      sidebarPanel(
        conditionalPanel( condition = "input.mytabs == 'Summary Statistics'",
              selectInput("ord","Sort the data?",
                   choices=c("Yes","No"),selected="No"), 
              checkboxGroupInput("which","Which Statistics should be calculated?",
                   choices=c("Sample Size","Mean","Median","Standard Deviation",
                      "First Quartile","Third Quartile","Interquartile Range","Other Percentiles"),
                   selected=c("Sample Size","Mean","Standard Deviation")),

              conditionalPanel(condition = "input.which.includes('Other Percentiles')",       
                    numericInput("p","Find Percentile",
                    value=90,min=1,max=99,step=1))
         ),
         conditionalPanel( condition = "input.mytabs == 'Frequency Table'",
               numericInput("nbins1","Number of Intervals?",
                      value=10,min=5,max=50)
         ),
         conditionalPanel( condition = "input.mytabs == 'Graphs'",
           radioButtons("graph","Which Graph?",
              choices=c("Histogram","Boxplot","Normal Probability Plot")),
           conditionalPanel( condition = "input.graph == 'Histogram'",
              selectInput("bin","Choice of Bins",
                     choices=c("Automatic","Manuel")), 
              conditionalPanel( condition = "input.bin == 'Manuel'",
                    numericInput("nbins","Number of Bins?",
                          value=20,min=5,max=1000)),
              selectInput("fit","Fitted Curve",
              choices=c("None","Normal Distribution","Nonparametric Density Estimate","Both"))
           ),
           selectInput("doPrint","Print Graph?",
              choices=c("No","pdf","png"),selected="No")    
         ),
         width=3
        ),
  mainPanel(
        tabsetPanel(
          tabPanel("Summary Statistics",
              uiOutput("text1"),
              uiOutput("text2")
          ),
          tabPanel("Frequency Table",
              uiOutput("table")
          ),
          tabPanel("Graphs",
              plotOutput("plot")
          ),
          id="mytabs")
        )
  )  
))

